Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ServerOption ¶
type ServerOption struct {
KubeClientOptions kube.ClientOptions
SchedulerNames []string
SchedulerConf string
SchedulePeriod time.Duration
EnableLeaderElection bool
LockObjectNamespace string
DefaultQueue string
PrintVersion bool
EnableMetrics bool
ListenAddress string
EnablePriorityClass bool
EnableCSIStorage bool
// vc-scheduler will load (not activate) custom plugins which are in this directory
PluginsDir string
EnableHealthz bool
// HealthzBindAddress is the IP address and port for the health check server to serve on
// defaulting to :11251
HealthzBindAddress string
// Parameters for scheduling tuning: the number of feasible nodes to find and score
MinNodesToFind int32
MinPercentageOfNodesToFind int32
PercentageOfNodesToFind int32
NodeSelector []string
}
ServerOption is the main context object for the controller manager.
var ServerOpts *ServerOption
ServerOpts server options.
func NewServerOption ¶
func NewServerOption() *ServerOption
NewServerOption creates a new CMServer with a default config.
func (*ServerOption) AddFlags ¶
func (s *ServerOption) AddFlags(fs *pflag.FlagSet)
AddFlags adds flags for a specific CMServer to the specified FlagSet.
func (*ServerOption) CheckOptionOrDie ¶
func (s *ServerOption) CheckOptionOrDie() error
CheckOptionOrDie check lock-object-namespace when LeaderElection is enabled.
func (*ServerOption) RegisterOptions ¶
func (s *ServerOption) RegisterOptions()
RegisterOptions registers options.
Click to show internal directories.
Click to hide internal directories.